# Data for Cadena et al. 2019 PlosCB

Data for the PlosCB 2019 paper **Deep convolutional models improve predictions of macaque V1 responses to natural images** 

The file `data_binned_responses/cadena_ploscb_data.pkl` contains the stimuli, extracted neuron spike counts, and metadata of Cadena et al., 2019 PlosCB. For more details about the data check the [paper](https://www.biorxiv.org/content/10.1101/201764v2).

**Loading the data**

To load the data you need python and the pickle library
```
import pickle
with open('binned_responses/cadena_ploscb_data.pkl', 'rb') as g:
    loaded_data = pickle.load(g)
```
**Check contents of data file**

```
[(i,loaded_data[i].shape) for i in loaded_data]
```
>>
```[('repetitions', (166,)),
 ('subject_id', (166,)),
 ('session_id', (166,)),
 ('image_ids', (7250, 1)),
 ('unit_id', (166,)),
 ('image_types', (7250, 1)),
 ('images', (7250, 140, 140)),
 ('responses', (4, 7250, 166)),
 ('image_numbers', (7250, 1))]
 ```


**Dictionary fields**

* `images`: The stimuli used in the paper. Array of shape `(num_images, width, height)`
* `responses`: The extracted spike count responses to those images in the same order. Array of shape `(num_repetitions, num_images, num_neurons)`. Aborted trials and fewer repetitions for some sessions resulted in NaNs in this array.
* `image_types`: Stimulus types of each image: 'original', 'conv1', conv2', conv3, or conv4. See paper for details.
* `unit_id`: identifier of the neurons
* `image_id`: identifier of the images
* `session_id`: identifier of the session for each neuron
* `subject_id`: identifier of the monkey for each neuron
* `repetitions`: Number of repeates of the entire stimulus during the session for each neuron.

This data is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/4.0/">Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International License</a>. This license requires that you contact us before you use the data in your own research. In particular, this means that you have to ask for permission if you intend to publish a new analysis performed with this data (no derivative works-clause).
